INSERT/asyncmy - Criterion.rs

## INSERT/asyncmy

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0022767 | 0.0023594 | 0.0022707
Mean | 9.0083 ms | 9.1492 ms | 9.2954 ms
Std. Dev. | 641.19 µs | 742.34 µs | 826.76 µs
Median | 8.7852 ms | 8.8455 ms | 9.0983 ms
MAD | 469.89 µs | 579.20 µs | 893.94 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.